@@ -101,9 +101,8 @@ class GitIssuePublisher(Publisher):
 
     def generate_report(self, data):
         report = [
-            "### Commit Review Summary\n",
+            f"### Commit Review Summary [{self.sha}]\n",
             f"**Author:** {self.user}\n",
-            f"**Commit SHA:** {self.sha}\n",
             f"**Message:**\n",
             f"- **Provided:** {data['message']['provided']}",
             f"- **Generated:** {data['message']['generated']}\n",
@@ -111,38 +110,83 @@ class GitIssuePublisher(Publisher):
             f"  *{data['message']['adherence']['comment']}*\n",
             "\n**Code Complexity:**\n",
             f"- **Comment:** {data['codeComplexity']['comment']}\n",
-            "\n**SOLID Principles Analysis:**\n"
+            "\n**Code Vulnerability:**\n",
+            f"- **Score:** {data['codeVulnerability']['score']} {data['codeVulnerability']['emoji']}",
+            f"  *{data['codeVulnerability']['comment']}*\n",
+            "\n**SOLID Principles Analysis:**\n",
+            "| Principle | Score | Comment |\n",
+            "|-----------|-------|---------|"
         ]
 
         for principle, details in data['codeSOLID'].items():
-            report.append(f"- **{principle.replace('_', ' ').title()}**")
-            report.append(f"  - **Score:** {details['score']} {details['emoji']}")
-            report.append(f"  *{details['comment']}*\n")
-
-        # Vulnerability section
-        report.append("**Code Vulnerability:**\n")
-        report.append(f"- **Score:** {data['codeVulnerability']['score']} {data['codeVulnerability']['emoji']}")
-        report.append(f"  *{data['codeVulnerability']['comment']}*\n")
+            principle_name = principle.replace('_', ' ').title()
+            score_emoji = f"{details['score']} {details['emoji']}"
+            comment = details['comment']
+            report.append(f"| {principle_name} | {score_emoji} | {comment} |\n")
 
         return '\n'.join(report)
 
     def append_data_to_comment(self, existing_body: str, adherence: Dict[str, Any]) -> str:
         """
-        Appends adherence data to the existing comment body.
+        Appends adherence data to the existing comment body as a chart.
 
         :param existing_body: The existing comment body.
         :param adherence: A dictionary with adherence score details.
         :return: The updated comment body.
         """
-        adherence_line = f"| {self.sha} | {adherence['score']} {adherence['emoji']} |"
-        if "| Commit | Score |\n|--------|-------|" in existing_body:
-            updated_body = existing_body.replace(
-                "|--------|-------|", f"|--------|-------|\n{adherence_line}"
-            )
-        else:
-            updated_body = existing_body + "\n\n**Adherence Scores History:**\n| Commit | Score |\n|--------|-------|\n" + adherence_line
+        # Extract existing scores from the current body
+        scores_history = self.extract_scores(existing_body)
+
+        # Append the new score
+        scores_history.append((self.sha, adherence['score']))
+
+        # Generate the new chart
+        score_chart = self.generate_score_chart(scores_history)
+
+        # Update the comment with the new chart
+        updated_body = existing_body.replace(
+            "\n**Adherence Scores History:**\n",
+            f"\n**Adherence Scores History:**\n{score_chart}\n"
+        )
         return updated_body
 
+    def generate_score_chart(self, scores_history: List[tuple]) -> str:
+        """
+        Generates a simple ASCII chart for the adherence scores.
+
+        :param scores_history: A list of tuples containing commit SHAs and scores.
+        :return: A string representing the ASCII chart.
+        """
+        max_score = max(score for _, score in scores_history)
+        chart = ["Adherence Score Chart\n"]
+
+        for sha, score in scores_history:
+            bar = '*' * (score * 10 // max_score)
+            chart.append(f"{sha[:7]}: {bar} ({score})")
+
+        return '\n'.join(chart)
+
+    def extract_scores(self, body: str) -> List[tuple]:
+        """
+        Extracts the adherence scores from the comment body.
+
+        :param body: The comment body.
+        :return: A list of tuples with commit SHAs and scores.
+        """
+        lines = body.splitlines()
+        scores_history = []
+
+        for line in lines:
+            if line.startswith("**Adherence Scores History:**"):
+                continue
+            if line.strip() and ':' in line:
+                parts = line.split(': ')
+                sha = parts[0].strip()
+                score_part = parts[1].strip().split(' ')
+                score = int(score_part[-1].strip('()'))
+                scores_history.append((sha, score))
+
+        return scores_history
     
 
 class WebPublisher(Publisher):
